@@ -59,9 +59,11 @@ class SpecialAttributesDict(dict):
 
     def __getitem__(self, key):
         if key == 'style':
+            # TODO: If detatched from a tag, this will throw an error.
+            #         Need to handle detatch and reattach for this attribute
             return self.tag.style
         elif key == 'class':
-            return dict.get(self, 'class', '')
+            return self.tag.className
 
         try:
             return dict.__getitem__(self, key)
@@ -69,7 +71,80 @@ class SpecialAttributesDict(dict):
             return None #  TODO: support undefined?
 
 
-    # TODO: Implement __delitem__
+    def __delitem__(self, key):
+        '''
+            __delitem__ - Called when someone does del tag.attributes['key']
+
+                @param key <str> - The attribute key to delete
+        '''
+        if key == 'style':
+            self.tag.style = ''
+            return
+        elif key == 'class':
+            self.tag.className = ''
+            return
+        else:
+            try:
+                return dict.__delitem__(self, key)
+            except KeyError:
+                return None
+
+
+    def __contains__(self, key):
+        # Hack in 'class' here
+        if key == 'class':
+            return bool( len(self.tag._classNames) > 0 )
+
+        return dict.__contains__(self, key)
+
+    def __iter__(self):
+        # Hack in 'class' here
+        self._handleClassAttr()
+
+        return dict.__iter__(self)
+
+
+    def pop(self, key):
+        raise TypeError('pop not supported on SpecialAttributesDict')
+
+    def setdefault(self, *args, **kwargs):
+        raise TypeError('setdefault not supported on SpecialAttributesDict')
+
+    def _handleClassAttr(self):
+        '''
+            _handleClassAttr - Hack to ensure "class" and "style" show up in attributes when classes are set,
+                and doesn't when no classes are present on associated tag.
+
+                TODO: I don't like this hack.
+        '''
+        if len(self.tag._classNames) > 0:
+            dict.__setitem__(self, "class", self.tag.className)
+        else:
+            try:
+                dict.__delitem__(self, "class")
+            except:
+                pass
+
+        styleAttr = self.tag.style
+        if styleAttr.isEmpty() is False:
+            dict.__setitem__(self, "style", styleAttr)
+        else:
+            try:
+                dict.__delitem__(self, "style")
+            except:
+                pass
+
+    def items(self):
+        # Intercept and apply the "class" attribute hack
+        self._handleClassAttr()
+
+        return dict.items(self)
+
+    def keys(self):
+        # Intercept and apply the "class" attribute hack
+        self._handleClassAttr()
+
+        return dict.keys(self)
 
     def get(self, key, default=None):
         '''
@@ -81,8 +156,10 @@ class SpecialAttributesDict(dict):
 
              @return - The value of attribute at #key, or #default if not present.
         '''
+        if key == 'class':
+            return self.tag.className
 
-        if key in {'style', 'class'} or key in self.keys():
+        if key in ('style', 'class') or key in self.keys():
             return self[key]
         return default
 
@@ -118,16 +195,28 @@ class SpecialAttributesDict(dict):
             else:
                 tag.style = value
         elif key == 'class':
-
-            # Ensure when we update the "class" attribute, that we update the list as well.
-            tag.classNames = [x for x in value.split(' ') if x]
-            dict.__setitem__(self, 'class',  value)
-            return value
+            # The setter for className will perform necessary stripping
+            tag.className = value
+            return
 
         dict.__setitem__(self, key,  value)
 
         return value
 
+    def __repr__(self):
+        self._handleClassAttr()
+
+        reprStr = dict.__repr__(self)
+        
+        return 'SpecialAttributesDict( %s )' %(reprStr, )
+
+    # __str__ already calls __repr__
+    #def __str__(self):
+    #    self._handleClassAttr()
+    #
+    #    strStr = dict.__str__(self)
+    #    return 'SpecialAttributesDict( %s )' %(strStr, )
+
 
 class AttributeNode(object):
     '''
@@ -428,6 +517,7 @@ class StyleAttribute(object):
             else: #if 'style' not in tagAttributes.keys():
                 tagAttributes._direct_set('style', self)
 
+
     def isEmpty(self):
         '''
             isEmpty - Check if this is an "empty" style (no attributes set)
