@@ -324,6 +324,64 @@ class AdvancedTag(object):
         '''
         return self.__class__(self.tagName, self.getAttributesList(), self.isSelfClosing)
 
+    def __getstate__(self):
+        '''
+            __getstate__ - Get state for pickling
+
+                @return <dict>
+        '''
+        state = dict()
+
+        getSelfAttr = lambda key : object.__getattribute__(self, key)
+
+        state['tagName'] = getSelfAttr('tagName')
+        state['attributesList'] = getSelfAttr('getAttributesList')()
+        state['isSelfClosing'] = getSelfAttr('isSelfClosing')
+        state['uid'] = getSelfAttr('uid')
+        state['ownerDocument'] = getSelfAttr('ownerDocument')
+
+        # "blocks" attribute covers both text and children
+        state['blocks'] = getSelfAttr('blocks')
+
+        return state
+
+
+    def __setstate__(self, state):
+        '''
+            __setstate__ - Set state when loading pickle
+
+                @param state <dict>
+        '''
+        # Call init on newly unpickled object to ensure everything is set properly
+        __init__ = object.__getattribute__(AdvancedTag, '__init__')
+        __init__(self, tagName=state['tagName'], attrList=state['attributesList'], isSelfClosing=state['isSelfClosing'])
+
+        # Copy the uid onto this object
+        self.uid = state['uid']
+
+        # Set the ownerDocument
+        self.ownerDocument = state['ownerDocument']
+
+        # Clear current blocks, so that we don't end up with multiple of the initial,
+        #   empty-string block used for indents
+        self.blocks = []
+
+        # Append children
+        for block in state['blocks']:
+            self.appendBlock(block)
+
+
+        #myAttributes = object.__getattribute__(self, '_attributes')
+
+        #for key, value in state['attributesList']:
+        #    if key == 'style':
+        ##        self.style = value
+        #    elif key == 'class':
+        #        self.className = value
+        #    else:
+        #        myAttributes._direct_set(key, value)
+                
+
     def appendText(self, text):
         '''
             appendText - append some inner text
@@ -334,6 +392,7 @@ class AdvancedTag(object):
         # self.blocks is either text or tags, in order of appearance
         self.blocks.append(text)
 
+
     def removeText(self, text):
         '''
             removeText - Removes the first occurace of given text in a text node (i.e. not part of a tag)
@@ -770,6 +829,76 @@ class AdvancedTag(object):
         '''
         return self.getAttributesList()
 
+
+    @property
+    def firstChild(self):
+        '''
+            firstChild - property, Get the first child block, text or tag.
+
+                @return <str/AdvancedTag/None> - The first child block, or None if no child blocks
+        '''
+        blocks = object.__getattribute__(self, 'blocks')
+        # First block is empty string for indent, but don't hardcode incase that changes
+        if blocks[0] == '':
+           firstIdx = 1
+        else:
+           firstIdx = 0
+
+        if len(blocks) == firstIdx:
+            # No first child
+            return None
+
+        return blocks[1]
+
+
+    @property
+    def firstElementChild(self):
+        '''
+            firstElementChild - property, Get the first child which is an element (AdvancedTag)
+
+                @return <AdvancedTag/None> - The first element child, or None if no element child nodes
+        '''
+        children = object.__getattribute__(self, 'children')
+
+        if len(children) == 0:
+            return None
+        return children[0]
+
+
+    @property
+    def lastChild(self):
+        '''
+            lastChild - property, Get the last child block, text or tag
+
+                @return <str/AdvancedTag/None> - The last child block, or None if no child blocks
+        '''
+        blocks = object.__getattribute__(self, 'blocks')
+        # First block is empty string for indent, but don't hardcode incase that changes
+        if blocks[0] == '':
+           firstIdx = 1
+        else:
+           firstIdx = 0
+
+        if len(blocks) <= firstIdx:
+            return None
+
+        return blocks[-1]
+
+
+    @property
+    def lastElementChild(self):
+        '''
+            lastElementChild - property, Get the last child which is an element (AdvancedTag)
+
+                @return <AdvancedTag/None> - The last element child, or None if no element child nodes
+        '''
+        children = object.__getattribute__(self, 'children')
+
+        if len(children) == 0:
+            return None
+        return children[-1]
+        
+
     @property
     def nextSibling(self):
         '''
@@ -797,9 +926,9 @@ class AdvancedTag(object):
         return parentNode.blocks[ myBlockIdx + 1 ]
 
     @property
-    def nextSiblingElement(self):
+    def nextElementSibling(self):
         '''
-            nextSiblingElement - Returns the next sibling that is an element.
+            nextElementSibling - Returns the next sibling that is an element.
                 This is the tag node following this node in the parent's list of children
 
                 @return <None/AdvancedTag> - None if there are no children (tag) in the parent after this node,
@@ -821,6 +950,8 @@ class AdvancedTag(object):
         # Else, return the next child in parent
         return parentNode.children[myElementIdx+1]
         
+    nextSiblingElement = nextElementSibling
+        
     @property
     def previousSibling(self):
         '''
@@ -849,9 +980,9 @@ class AdvancedTag(object):
         return parentNode.blocks[myBlockIdx-1]
 
     @property
-    def previousSiblingElement(self):
+    def previousElementSibling(self):
         '''
-            previousSiblingElement - Returns the previous  sibling  that is an element. 
+            previousElementSibling - Returns the previous  sibling  that is an element. 
 
                                         This is the previous tag node in the parent's list of children
 
@@ -876,6 +1007,8 @@ class AdvancedTag(object):
         # Else, return previous element tag
         return parentNode.children[myElementIdx-1]
 
+    previousSiblingElement = previousElementSibling
+
 
     @property
     def tagBlocks(self):
